import { useEffect, useState } from 'react';
import PropTypes from 'prop-types';
import { useMount } from '@s-ui/react-hooks';
import { loadScript } from './helper.js';
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
var ScriptLoader = function ScriptLoader(_ref) {
  var src = _ref.src,
    verifier = _ref.verifier,
    _ref$isAsync = _ref.isAsync,
    isAsync = _ref$isAsync === void 0 ? true : _ref$isAsync,
    _ref$detectionDelay = _ref.detectionDelay,
    detectionDelay = _ref$detectionDelay === void 0 ? 5000 : _ref$detectionDelay,
    _ref$onTimeout = _ref.onTimeout,
    onTimeout = _ref$onTimeout === void 0 ? function () {} : _ref$onTimeout,
    stylesheet = _ref.stylesheet,
    render = _ref.render,
    _ref$timeoutRender = _ref.timeoutRender,
    timeoutRender = _ref$timeoutRender === void 0 ? function () {
      return null;
    } : _ref$timeoutRender;
  var _useState = useState(false),
    readyToRender = _useState[0],
    setReadyToRender = _useState[1];
  var _useState2 = useState(false),
    timeout = _useState2[0],
    seTimeout = _useState2[1];
  var initLoad = function initLoad() {
    loadScript({
      src: src,
      verifier: verifier,
      isAsync: isAsync,
      detectionDelay: detectionDelay,
      stylesheet: stylesheet
    }).then(function () {
      return setReadyToRender(true);
    }).catch(function () {
      return seTimeout(true);
    });
  };
  useEffect(function () {
    return onTimeout();
  }, [onTimeout, timeout]);
  useMount(initLoad);
  if (readyToRender && render) return render();
  if (timeout && timeoutRender) return timeoutRender();
  return /*#__PURE__*/_jsx(_Fragment, {});
};
ScriptLoader.displayName = 'ScriptLoader';
ScriptLoader.propTypes = {
  /**
   * The script to be injected
   */
  src: PropTypes.string.isRequired,
  /**
   * A function that will return a truthy value when the resource is loaded, false otherwise
   */
  verifier: PropTypes.func.isRequired,
  /**
   * A function that will return what should be rendered when the script is loaded
   */
  render: PropTypes.func.isRequired,
  /**
   * A function that will return what should be rendered when the script is not
   * loaded within the expected time.
   */
  timeoutRender: PropTypes.func,
  /**
   * A function that will be executed when the script is not loaded within the
   * expected time.
   */
  onTimeout: PropTypes.func,
  /**
   * If the script should be marked as async or not
   */
  isAsync: PropTypes.bool,
  /**
   * Detection delay time (in miliseconds)
   */
  detectionDelay: PropTypes.number,
  /**
   * Stylesheet to be injected
   */
  stylesheet: PropTypes.string
};
export default ScriptLoader;